@@ -1,4 +1,4 @@
-// $Id: blacklist.c,v 1.4 2002/11/18 21:58:18 ensc Exp $    --*- c++ -*--
+// $Id: blacklist.c,v 1.7 2002/11/27 21:16:05 ensc Exp $    --*- c++ -*--
 
 // Copyright (C) 2002 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -85,7 +85,7 @@ IPData_searchCompare(void const *lhs_v, void const *rhs_v)
 static int
 IPData_sortCompare(void const *lhs_v, void const *rhs_v)
 {
-  struct IPData const *	lhs = lhs_v;
+  struct IPData const *		lhs = lhs_v;
   assert(lhs!=0);
   
   return IPData_searchCompare(&lhs->ip, rhs_v);
@@ -96,9 +96,24 @@ NetData_sortCompare(void const *lhs_v, void const *rhs_v)
 {
   struct NetData const *	lhs = lhs_v;
   struct NetData const *	rhs = rhs_v;
+  int				result;
   assert(lhs!=0 && rhs!=0);
   
-  return -getBitCount(lhs->mask.s_addr) + getBitCount(rhs->mask.s_addr);
+  result = -getBitCount(lhs->mask.s_addr) + getBitCount(rhs->mask.s_addr);
+
+#if ENSC_TESTSUITE
+    // When being in testsuite-mode compare the network-data in a more deterministic way. Else,
+    // different bsort() implementations can sort elements in a different order when they compare
+    // equally and the expected output will differ from the actual one.
+  if      (result!=0) {}
+  else if (ntohl(lhs->mask.s_addr) < ntohl(rhs->mask.s_addr)) result = -1;
+  else if (ntohl(lhs->mask.s_addr) > ntohl(rhs->mask.s_addr)) result = +1;
+  else if (ntohl(lhs->ip.s_addr) < ntohl(rhs->ip.s_addr))     result = -1;
+  else if (ntohl(lhs->ip.s_addr) > ntohl(rhs->ip.s_addr))     result = +1;
+  else result = lhs->status - rhs->status;
+#endif  
+
+  return result;
 }
 
 void
@@ -191,13 +206,13 @@ BlackList_parseLine(BlackList *lst, char *start, char const *end, size_t line_nr
       return false;
     }
     else {
-      parse_mask.s_addr = 0;
-      for (; val>0; --val) {
-	parse_mask.s_addr >>= 1;
-	parse_mask.s_addr  |= 0x80000000;
+	// Avoid (~0u << 32) because this gives ~0u, but not 0.
+      parse_mask.s_addr   = ~0u;
+      if (val<32) {
+	parse_mask.s_addr <<= (32-val-1);
+	parse_mask.s_addr <<= 1;
       }
-
-      parse_mask.s_addr = htonl(parse_mask.s_addr);
+      parse_mask.s_addr   = htonl(parse_mask.s_addr);
     }
 
     if (pos<end) start = pos+1;
@@ -416,7 +431,8 @@ BlackList_getMac(BlackList const *lst_const, struct in_addr const ip, struct eth
       {
 	time_t			t = time(0);
 
-	res->ether_addr_octet[5] = (rand()%32 + t/30000)%256;
+	res->ether_addr_octet[5]  = (rand()%BLACKLIST_RAND_COUNT +
+				     t/BLACKLIST_RAND_PERIOD)%256;
 	break;
       }
       default		:  assert(false); result = 0; break;
@@ -433,11 +449,11 @@ BlackList_print(BlackList *lst, int fd)
   assert(lst!=0);
   
   {
-    struct IPData const	*i;
+    struct IPData const		*i;
 
     for (i =Vector_begin(&lst->ip_list);
 	 i!=Vector_end(&lst->ip_list); ++i) {
-      char	*aux = ether_ntoa(&i->mac);
+      char *		aux = ether_ntoa(&i->mac);
       
       switch (i->status) {
 	case blUNDECIDED	:  write(fd, "?", 1); break;
